@@ -20,7 +20,7 @@ class SpatialSoftmax(tf.keras.layers.Layer):
         posx, posy = tf.meshgrid(tf.linspace(-1., 1., num=H),
                                  tf.linspace(-1., 1., num=W))
 
-        self.image_coords = tf.stack([posx, posy], axis=-1)
+        self.image_coords = tf.cast(tf.stack([posx, posy], axis=-1), dtype=self.compute_dtype)
 
     def call(self, inputs, **kwargs):
         N, H, W, C = list(inputs.shape)
